/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'ka', {
	border: 'ჩარჩოს გამოჩენა',
	noUrl: 'აკრიფეთ iframe-ის URL',
	scrolling: 'გადახვევის ზოლების დაშვება',
	title: 'IFrame-ის პარამეტრები',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
